declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        sectionTitle?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                env: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                secrets: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    env: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    secrets: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit: string[];
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            env: {
                MY_VAR: string;
            };
            secrets: {
                API_KEY: string;
            };
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    env: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    secrets: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit: string[];
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            env: string[];
            secrets: string[];
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=org.d.ts.map