declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodString;
                    homepage_url: import("zod").ZodString;
                    icon: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    client_type: import("zod").ZodOptional<import("zod").ZodEnum<{
                        public: "public";
                        confidential: "confidential";
                    }>>;
                    redirect_uris: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    post_logout_redirect_uris: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    grant_types: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    response_types: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    scopes: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    project_id: import("zod").ZodOptional<import("zod").ZodString>;
                    access_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    refresh_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    id_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    allowed_user_ids: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    is_public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                stripRequired?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                client: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodString;
                    homepage_url: import("zod").ZodString;
                    icon: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    client_type: import("zod").ZodEnum<{
                        public: "public";
                        confidential: "confidential";
                    }>;
                    redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                    post_logout_redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                    grant_types: import("zod").ZodArray<import("zod").ZodString>;
                    response_types: import("zod").ZodArray<import("zod").ZodString>;
                    scopes: import("zod").ZodArray<import("zod").ZodString>;
                    org_id: import("zod").ZodOptional<import("zod").ZodString>;
                    project_id: import("zod").ZodOptional<import("zod").ZodString>;
                    access_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    refresh_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    id_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    allowed_user_ids: import("zod").ZodArray<import("zod").ZodString>;
                    internal: import("zod").ZodDefault<import("zod").ZodOptional<import("zod").ZodBoolean>>;
                    is_public: import("zod").ZodDefault<import("zod").ZodBoolean>;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                client_secret: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            description: string;
            homepage_url: string;
            redirect_uris: string[];
            scopes: string[];
        };
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodString;
                description: import("zod").ZodString;
                homepage_url: import("zod").ZodString;
                icon: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                client_type: import("zod").ZodEnum<{
                    public: "public";
                    confidential: "confidential";
                }>;
                redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                post_logout_redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                grant_types: import("zod").ZodArray<import("zod").ZodString>;
                response_types: import("zod").ZodArray<import("zod").ZodString>;
                scopes: import("zod").ZodArray<import("zod").ZodString>;
                org_id: import("zod").ZodOptional<import("zod").ZodString>;
                project_id: import("zod").ZodOptional<import("zod").ZodString>;
                access_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                refresh_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                id_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                allowed_user_ids: import("zod").ZodArray<import("zod").ZodString>;
                internal: import("zod").ZodDefault<import("zod").ZodOptional<import("zod").ZodBoolean>>;
                is_public: import("zod").ZodDefault<import("zod").ZodBoolean>;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
                user_count: import("zod").ZodNumber;
                last_activity: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                link: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    homepage_url: import("zod").ZodOptional<import("zod").ZodString>;
                    icon: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    client_type: import("zod").ZodOptional<import("zod").ZodEnum<{
                        public: "public";
                        confidential: "confidential";
                    }>>;
                    redirect_uris: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    post_logout_redirect_uris: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    grant_types: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    response_types: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    scopes: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    project_id: import("zod").ZodOptional<import("zod").ZodString>;
                    access_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    refresh_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    id_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    allowed_user_ids: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    is_public: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
                stripRequired: boolean;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                client: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodString;
                    homepage_url: import("zod").ZodString;
                    icon: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    client_type: import("zod").ZodEnum<{
                        public: "public";
                        confidential: "confidential";
                    }>;
                    redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                    post_logout_redirect_uris: import("zod").ZodArray<import("zod").ZodString>;
                    grant_types: import("zod").ZodArray<import("zod").ZodString>;
                    response_types: import("zod").ZodArray<import("zod").ZodString>;
                    scopes: import("zod").ZodArray<import("zod").ZodString>;
                    org_id: import("zod").ZodOptional<import("zod").ZodString>;
                    project_id: import("zod").ZodOptional<import("zod").ZodString>;
                    access_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    refresh_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    id_token_lifetime_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    allowed_user_ids: import("zod").ZodArray<import("zod").ZodString>;
                    internal: import("zod").ZodDefault<import("zod").ZodOptional<import("zod").ZodBoolean>>;
                    is_public: import("zod").ZodDefault<import("zod").ZodBoolean>;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                client_secret: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            scopes: string[];
            description?: undefined;
            homepage_url?: undefined;
            redirect_uris?: undefined;
        };
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                deleted: import("zod").ZodLiteral<true>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                client_id: import("zod").ZodString;
                client_secret: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                user_id: import("zod").ZodString;
                scopes: import("zod").ZodArray<import("zod").ZodString>;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                activity_date: import("zod").ZodString;
                total_access: import("zod").ZodNumber;
                unique_users: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                client_id: import("zod").ZodString;
                activity_date: import("zod").ZodString;
                unique_users: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                client_id: import("zod").ZodString;
                scopes: import("zod").ZodArray<import("zod").ZodString>;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
                client_name: import("zod").ZodString;
                client_description: import("zod").ZodString;
                client_icon: import("zod").ZodNullable<import("zod").ZodString>;
                client_homepage_url: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                scopes: import("zod").ZodArray<import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodString;
                    consent_title: import("zod").ZodString;
                    consent_description: import("zod").ZodString;
                    sensitive: import("zod").ZodBoolean;
                    required: import("zod").ZodBoolean;
                    default: import("zod").ZodBoolean;
                }, import("zod/v4/core").$strip>>;
                permissions: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    label: import("zod").ZodString;
                    groups: import("zod").ZodArray<import("zod").ZodObject<{
                        id: import("zod").ZodString;
                        name: import("zod").ZodString;
                        description: import("zod").ZodString;
                        levels: import("zod").ZodArray<import("zod").ZodObject<{
                            label: import("zod").ZodString;
                            value: import("zod").ZodString;
                            scopes: import("zod").ZodArray<import("zod").ZodString>;
                            warning: import("zod").ZodOptional<import("zod").ZodBoolean>;
                            warningTitle: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                first_name: import("zod").ZodNullable<import("zod").ZodString>;
                last_name: import("zod").ZodNullable<import("zod").ZodString>;
                email: import("zod").ZodNullable<import("zod").ZodString>;
                photo_url: import("zod").ZodNullable<import("zod").ZodString>;
                role: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                rotated: import("zod").ZodLiteral<true>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=oauth.d.ts.map