declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    tags: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    orgId: import("zod").ZodString;
                    cloudRegion: import("zod").ZodString;
                    domains: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    generation: import("zod").ZodOptional<import("zod").ZodString>;
                    provider: import("zod").ZodOptional<import("zod").ZodString>;
                    framework: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                sdkKey: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            orgId: string;
            cloudRegion: string;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    ids: import("zod").ZodArray<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            ids: string[];
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    cloudRegion: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            cloudRegion: string;
            name?: undefined;
            orgId?: undefined;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    env: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    secrets: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit: string[];
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            env: {
                DB_HOST: string;
            };
            secrets: {
                DB_PASS: string;
            };
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    env: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    secrets: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit: string[];
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            env: string[];
            secrets: string[];
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                name: import("zod").ZodString;
                description: import("zod").ZodNullable<import("zod").ZodString>;
                identifier: import("zod").ZodString;
                deploymentId: import("zod").ZodNullable<import("zod").ZodString>;
                devmode: import("zod").ZodBoolean;
                metadata: import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                createdAt: import("zod").ZodString;
                updatedAt: import("zod").ZodString;
                evals: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodNullable<import("zod").ZodString>;
                    identifier: import("zod").ZodNullable<import("zod").ZodString>;
                    devmode: import("zod").ZodBoolean;
                    createdAt: import("zod").ZodString;
                    updatedAt: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    resources: import("zod").ZodOptional<import("zod").ZodObject<{
                        memory: import("zod").ZodDefault<import("zod").ZodString>;
                        cpu: import("zod").ZodDefault<import("zod").ZodString>;
                        disk: import("zod").ZodDefault<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                    mode: import("zod").ZodOptional<import("zod").ZodObject<{
                        type: import("zod").ZodDefault<import("zod").ZodEnum<{
                            "on-demand": "on-demand";
                            provisioned: "provisioned";
                        }>>;
                        idle: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                    dependencies: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                    domains: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                orgId: import("zod").ZodString;
                publicKey: import("zod").ZodString;
                buildLogsStreamURL: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            resources: {
                memory: number;
                cpu: number;
            };
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            error?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                streamId: import("zod").ZodOptional<import("zod").ZodString>;
                rolloutId: import("zod").ZodOptional<import("zod").ZodString>;
                publicUrls: import("zod").ZodObject<{
                    latest: import("zod").ZodString;
                    deployment: import("zod").ZodString;
                    custom: import("zod").ZodArray<import("zod").ZodString>;
                    vanityDeployment: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    vanityProject: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                state: import("zod").ZodEnum<{
                    pending: "pending";
                    building: "building";
                    deploying: "deploying";
                    failed: "failed";
                    completed: "completed";
                }>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    error: import("zod").ZodOptional<import("zod").ZodString>;
                    diagnostics: import("zod").ZodOptional<import("zod").ZodObject<{
                        success: import("zod").ZodBoolean;
                        errors: import("zod").ZodArray<import("zod").ZodObject<{
                            type: import("zod").ZodEnum<{
                                file: "file";
                                general: "general";
                            }>;
                            scope: import("zod").ZodEnum<{
                                build: "build";
                                typescript: "typescript";
                                ast: "ast";
                                bundler: "bundler";
                                validation: "validation";
                                deploy: "deploy";
                            }>;
                            path: import("zod").ZodOptional<import("zod").ZodString>;
                            line: import("zod").ZodOptional<import("zod").ZodNumber>;
                            column: import("zod").ZodOptional<import("zod").ZodNumber>;
                            message: import("zod").ZodString;
                            code: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                        warnings: import("zod").ZodArray<import("zod").ZodObject<{
                            type: import("zod").ZodEnum<{
                                file: "file";
                                general: "general";
                            }>;
                            scope: import("zod").ZodEnum<{
                                build: "build";
                                typescript: "typescript";
                                ast: "ast";
                                bundler: "bundler";
                                validation: "validation";
                                deploy: "deploy";
                            }>;
                            path: import("zod").ZodOptional<import("zod").ZodString>;
                            line: import("zod").ZodOptional<import("zod").ZodNumber>;
                            column: import("zod").ZodOptional<import("zod").ZodNumber>;
                            message: import("zod").ZodString;
                            code: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                        diagnostics: import("zod").ZodArray<import("zod").ZodObject<{
                            name: import("zod").ZodString;
                            startedAt: import("zod").ZodString;
                            completedAt: import("zod").ZodString;
                            durationMs: import("zod").ZodNumber;
                        }, import("zod/v4/core").$strip>>;
                        error: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            error: string;
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            hostname?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                hostname: import("zod").ZodNullable<import("zod").ZodString>;
                url: import("zod").ZodNullable<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    projectId: import("zod").ZodString;
                    hostname: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                hostname: import("zod").ZodString;
                url: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            hostname: string;
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            error?: undefined;
            ecosystem?: undefined;
            packages?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    ecosystem: import("zod").ZodString;
                    packages: import("zod").ZodArray<import("zod").ZodObject<{
                        name: import("zod").ZodString;
                        version: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
                omit?: undefined;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                action: import("zod").ZodEnum<{
                    allow: "allow";
                    block: "block";
                }>;
                summary: import("zod").ZodObject<{
                    scanned: import("zod").ZodNumber;
                    flagged: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>;
                findings: import("zod").ZodArray<import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    version: import("zod").ZodString;
                    reason: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
                list: import("zod").ZodOptional<import("zod").ZodObject<{
                    fetchedAt: import("zod").ZodString;
                    count: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>>;
                error: import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            ecosystem: string;
            packages: {
                name: string;
                version: string;
            }[];
            name?: undefined;
            orgId?: undefined;
            cloudRegion?: undefined;
            ids?: undefined;
            env?: undefined;
            secrets?: undefined;
            resources?: undefined;
            error?: undefined;
            hostname?: undefined;
        };
    })[];
};
export default service;
//# sourceMappingURL=project.d.ts.map