declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
                deleted: import("zod").ZodBoolean;
                deleted_at: import("zod").ZodNullable<import("zod").ZodString>;
                deleted_by: import("zod").ZodNullable<import("zod").ZodString>;
                org_id: import("zod").ZodString;
                project_id: import("zod").ZodString;
                user_data: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=thread.d.ts.map