declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodOptional<import("zod").ZodString>;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    queue_type: import("zod").ZodEnum<{
                        worker: "worker";
                        pubsub: "pubsub";
                    }>;
                    internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    settings: import("zod").ZodOptional<import("zod").ZodObject<{
                        default_ttl_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>>;
                        default_visibility_timeout_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_max_retries: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_backoff_ms: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_max_backoff_ms: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_multiplier: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        max_in_flight_per_client: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        retention_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            queue_type: string;
            description: string;
            settings: {
                default_max_retries: number;
                default_visibility_timeout_seconds: number;
            };
            payload?: undefined;
            metadata?: undefined;
            messages?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
            timeout_seconds?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                queues: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
                    queue_type: import("zod").ZodEnum<{
                        worker: "worker";
                        pubsub: "pubsub";
                    }>;
                    default_ttl_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    default_visibility_timeout_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    default_max_retries: import("zod").ZodOptional<import("zod").ZodNumber>;
                    default_retry_backoff_ms: import("zod").ZodOptional<import("zod").ZodNumber>;
                    default_retry_max_backoff_ms: import("zod").ZodOptional<import("zod").ZodNumber>;
                    default_retry_multiplier: import("zod").ZodOptional<import("zod").ZodNumber>;
                    max_in_flight_per_client: import("zod").ZodOptional<import("zod").ZodNumber>;
                    next_offset: import("zod").ZodOptional<import("zod").ZodNumber>;
                    message_count: import("zod").ZodOptional<import("zod").ZodNumber>;
                    dlq_count: import("zod").ZodOptional<import("zod").ZodNumber>;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                    paused_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    retention_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodOptional<import("zod").ZodNumber>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    settings: import("zod").ZodOptional<import("zod").ZodObject<{
                        default_ttl_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>>;
                        default_visibility_timeout_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_max_retries: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_backoff_ms: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_max_backoff_ms: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        default_retry_multiplier: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        max_in_flight_per_client: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                        retention_seconds: import("zod").ZodOptional<import("zod").ZodOptional<import("zod").ZodNumber>>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            description: string;
            settings: {
                default_max_retries: number;
                default_visibility_timeout_seconds?: undefined;
            };
            name?: undefined;
            queue_type?: undefined;
            payload?: undefined;
            metadata?: undefined;
            messages?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
            timeout_seconds?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name?: undefined;
            queue_type?: undefined;
            description?: undefined;
            settings?: undefined;
            payload?: undefined;
            metadata?: undefined;
            messages?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
            timeout_seconds?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    payload: import("zod").ZodUnknown;
                    metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                    idempotency_key: import("zod").ZodOptional<import("zod").ZodString>;
                    partition_key: import("zod").ZodOptional<import("zod").ZodString>;
                    ttl_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            payload: {
                orderId: number;
                action: string;
            };
            metadata: {
                priority: string;
            };
            name?: undefined;
            queue_type?: undefined;
            description?: undefined;
            settings?: undefined;
            messages?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
            timeout_seconds?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    messages: import("zod").ZodArray<import("zod").ZodObject<{
                        payload: import("zod").ZodUnknown;
                        metadata: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                        idempotency_key: import("zod").ZodOptional<import("zod").ZodString>;
                        partition_key: import("zod").ZodOptional<import("zod").ZodString>;
                        ttl_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                    }, import("zod/v4/core").$strip>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                messages: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    queue_id: import("zod").ZodString;
                    offset: import("zod").ZodNumber;
                    payload: import("zod").ZodUnknown;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                    metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                    state: import("zod").ZodOptional<import("zod").ZodEnum<{
                        pending: "pending";
                        failed: "failed";
                        leased: "leased";
                        processing: "processing";
                        delivered: "delivered";
                        dead: "dead";
                    }>>;
                    idempotency_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    partition_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    ttl_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    delivery_attempts: import("zod").ZodOptional<import("zod").ZodNumber>;
                    max_retries: import("zod").ZodOptional<import("zod").ZodNumber>;
                    published_at: import("zod").ZodOptional<import("zod").ZodString>;
                    expires_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    delivered_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    acknowledged_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    created_at: import("zod").ZodOptional<import("zod").ZodString>;
                    updated_at: import("zod").ZodOptional<import("zod").ZodString>;
                    source_id: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    source_name: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>>;
                failed: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodNumber>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            messages: {
                payload: {
                    orderId: number;
                };
            }[];
            name?: undefined;
            queue_type?: undefined;
            description?: undefined;
            settings?: undefined;
            payload?: undefined;
            metadata?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
            timeout_seconds?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                messages: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    queue_id: import("zod").ZodString;
                    offset: import("zod").ZodNumber;
                    payload: import("zod").ZodUnknown;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                    metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                    state: import("zod").ZodOptional<import("zod").ZodEnum<{
                        pending: "pending";
                        failed: "failed";
                        leased: "leased";
                        processing: "processing";
                        delivered: "delivered";
                        dead: "dead";
                    }>>;
                    idempotency_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    partition_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    ttl_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    delivery_attempts: import("zod").ZodOptional<import("zod").ZodNumber>;
                    max_retries: import("zod").ZodOptional<import("zod").ZodNumber>;
                    published_at: import("zod").ZodOptional<import("zod").ZodString>;
                    expires_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    delivered_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    acknowledged_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    created_at: import("zod").ZodOptional<import("zod").ZodString>;
                    updated_at: import("zod").ZodOptional<import("zod").ZodString>;
                    source_id: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    source_name: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                message: import("zod").ZodNullable<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    queue_id: import("zod").ZodString;
                    offset: import("zod").ZodNumber;
                    payload: import("zod").ZodUnknown;
                    size: import("zod").ZodOptional<import("zod").ZodNumber>;
                    metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                    state: import("zod").ZodOptional<import("zod").ZodEnum<{
                        pending: "pending";
                        failed: "failed";
                        leased: "leased";
                        processing: "processing";
                        delivered: "delivered";
                        dead: "dead";
                    }>>;
                    idempotency_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    partition_key: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    ttl_seconds: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    delivery_attempts: import("zod").ZodOptional<import("zod").ZodNumber>;
                    max_retries: import("zod").ZodOptional<import("zod").ZodNumber>;
                    published_at: import("zod").ZodOptional<import("zod").ZodString>;
                    expires_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    delivered_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    acknowledged_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    created_at: import("zod").ZodOptional<import("zod").ZodString>;
                    updated_at: import("zod").ZodOptional<import("zod").ZodString>;
                    source_id: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    source_name: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                offset: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    destination_type: import("zod").ZodEnum<{
                        url: "url";
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        sandbox: "sandbox";
                        http: "http";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                    enabled: import("zod").ZodDefault<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            destination_type: string;
            config: {
                url: string;
            };
            enabled: boolean;
            queue_type?: undefined;
            description?: undefined;
            settings?: undefined;
            payload?: undefined;
            metadata?: undefined;
            messages?: undefined;
            timeout_seconds?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                destinations: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    queue_id: import("zod").ZodString;
                    destination_type: import("zod").ZodEnum<{
                        url: "url";
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        sandbox: "sandbox";
                        http: "http";
                    }>;
                    config: import("zod").ZodUnion<readonly [import("zod").ZodObject<{
                        url: import("zod").ZodString;
                        headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                        method: import("zod").ZodDefault<import("zod").ZodString>;
                        timeout_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                        retry_policy: import("zod").ZodOptional<import("zod").ZodObject<{
                            max_attempts: import("zod").ZodDefault<import("zod").ZodNumber>;
                            initial_backoff_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                            max_backoff_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                            backoff_multiplier: import("zod").ZodDefault<import("zod").ZodNumber>;
                        }, import("zod/v4/core").$strip>>;
                        signing: import("zod").ZodOptional<import("zod").ZodObject<{
                            enabled: import("zod").ZodDefault<import("zod").ZodBoolean>;
                            secret_key: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                    }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                        url: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                        url: import("zod").ZodString;
                        headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                        method: import("zod").ZodDefault<import("zod").ZodString>;
                        timeout_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                        retry_policy: import("zod").ZodOptional<import("zod").ZodObject<{
                            max_attempts: import("zod").ZodDefault<import("zod").ZodNumber>;
                            initial_backoff_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                            max_backoff_ms: import("zod").ZodDefault<import("zod").ZodNumber>;
                            backoff_multiplier: import("zod").ZodDefault<import("zod").ZodNumber>;
                        }, import("zod/v4/core").$strip>>;
                        signing: import("zod").ZodOptional<import("zod").ZodObject<{
                            enabled: import("zod").ZodDefault<import("zod").ZodBoolean>;
                            secret_key: import("zod").ZodOptional<import("zod").ZodString>;
                        }, import("zod/v4/core").$strip>>;
                    }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                        queue_id: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                        sandbox_id: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>, import("zod").ZodObject<{
                        email_address: import("zod").ZodString;
                    }, import("zod/v4/core").$strip>, import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>]>;
                    enabled: import("zod").ZodBoolean;
                    stats: import("zod").ZodOptional<import("zod").ZodObject<{
                        total_deliveries: import("zod").ZodNumber;
                        successful_deliveries: import("zod").ZodNumber;
                        failed_deliveries: import("zod").ZodNumber;
                        last_delivery_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        last_success_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                        last_failure_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    }, import("zod/v4/core").$strip>>;
                    success_count: import("zod").ZodOptional<import("zod").ZodNumber>;
                    failure_count: import("zod").ZodOptional<import("zod").ZodNumber>;
                    last_success_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    last_failure_at: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    last_failure_error: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    created_at: import("zod").ZodString;
                    updated_at: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            timeout_seconds: number;
            name?: undefined;
            queue_type?: undefined;
            description?: undefined;
            settings?: undefined;
            payload?: undefined;
            metadata?: undefined;
            messages?: undefined;
            destination_type?: undefined;
            config?: undefined;
            enabled?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                deliveries: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    destination_id: import("zod").ZodString;
                    queue_id: import("zod").ZodString;
                    message_id: import("zod").ZodString;
                    payload: import("zod").ZodOptional<import("zod").ZodUnknown>;
                    status: import("zod").ZodEnum<{
                        success: "success";
                        pending: "pending";
                        failed: "failed";
                    }>;
                    http_status_code: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodNumber>>;
                    error: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    duration_ms: import("zod").ZodOptional<import("zod").ZodNumber>;
                    attempt_number: import("zod").ZodOptional<import("zod").ZodNumber>;
                    request_headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    response_headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                    delivered_at: import("zod").ZodString;
                    created_at: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                messages: import("zod").ZodArray<import("zod").ZodObject<{
                    id: import("zod").ZodString;
                    queue_id: import("zod").ZodString;
                    original_message_id: import("zod").ZodOptional<import("zod").ZodString>;
                    offset: import("zod").ZodNumber;
                    payload: import("zod").ZodUnknown;
                    metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
                    failure_reason: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                    delivery_attempts: import("zod").ZodNumber;
                    moved_at: import("zod").ZodOptional<import("zod").ZodString>;
                    original_published_at: import("zod").ZodOptional<import("zod").ZodString>;
                    published_at: import("zod").ZodOptional<import("zod").ZodString>;
                    created_at: import("zod").ZodString;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodOptional<import("zod").ZodNumber>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=queue.d.ts.map