declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                instanceId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                privateIPv4: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                availabilityZone: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                instanceType: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                instanceTags: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodArray<import("zod").ZodString>>>;
                deploymentCount: import("zod").ZodOptional<import("zod").ZodNumber>;
                status: import("zod").ZodString;
                provider: import("zod").ZodString;
                region: import("zod").ZodString;
                startedAt: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                stoppedAt: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                pausedAt: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                erroredAt: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                error: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                orgId: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                orgName: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                createdAt: import("zod").ZodString;
                updatedAt: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodString>>;
                metadata: import("zod").ZodOptional<import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>>;
            }, import("zod/v4/core").$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    orgId: import("zod").ZodString;
                    publicKey: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                orgId: import("zod").ZodString;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            orgId: string;
            publicKey: string;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                publicKey: import("zod").ZodNullable<import("zod").ZodString>;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=machine.d.ts.map