import { z } from 'zod';
declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                workflows: z.ZodArray<z.ZodObject<{
                    id: z.ZodString;
                    created_at: z.ZodString;
                    updated_at: z.ZodString;
                    created_by: z.ZodString;
                    org_id: z.ZodString;
                    name: z.ZodString;
                    description: z.ZodNullable<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    status: z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>;
                    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    execution_count: z.ZodOptional<z.ZodNumber>;
                    link: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>;
                total: z.ZodNumber;
            }, z.core.$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                workflow: z.ZodObject<{
                    id: z.ZodString;
                    created_at: z.ZodString;
                    updated_at: z.ZodString;
                    created_by: z.ZodString;
                    org_id: z.ZodString;
                    name: z.ZodString;
                    description: z.ZodNullable<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    status: z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>;
                    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    execution_count: z.ZodOptional<z.ZodNumber>;
                    link: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    name: z.ZodString;
                    description: z.ZodOptional<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                workflow: z.ZodObject<{
                    id: z.ZodString;
                    created_at: z.ZodString;
                    updated_at: z.ZodString;
                    created_by: z.ZodString;
                    org_id: z.ZodString;
                    name: z.ZodString;
                    description: z.ZodNullable<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    status: z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>;
                    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    execution_count: z.ZodOptional<z.ZodNumber>;
                    link: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>;
            }, z.core.$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            source_type: string;
            source_ref_id: string;
            status?: undefined;
            graph_json?: undefined;
            payload?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    name: z.ZodOptional<z.ZodString>;
                    description: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                    status: z.ZodOptional<z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                workflow: z.ZodObject<{
                    id: z.ZodString;
                    created_at: z.ZodString;
                    updated_at: z.ZodString;
                    created_by: z.ZodString;
                    org_id: z.ZodString;
                    name: z.ZodString;
                    description: z.ZodNullable<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    status: z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>;
                    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    execution_count: z.ZodOptional<z.ZodNumber>;
                    link: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            status: string;
            source_type?: undefined;
            source_ref_id?: undefined;
            graph_json?: undefined;
            payload?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    nodes: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        type: z.ZodOptional<z.ZodString>;
                        position: z.ZodOptional<z.ZodObject<{
                            x: z.ZodNumber;
                            y: z.ZodNumber;
                        }, z.core.$strip>>;
                        data: z.ZodOptional<z.ZodUnknown>;
                    }, z.core.$strip>>;
                    edges: z.ZodArray<z.ZodObject<{
                        id: z.ZodString;
                        source: z.ZodString;
                        target: z.ZodString;
                        sourceHandle: z.ZodOptional<z.ZodString>;
                        targetHandle: z.ZodOptional<z.ZodString>;
                    }, z.core.$strip>>;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                workflow: z.ZodObject<{
                    id: z.ZodString;
                    created_at: z.ZodString;
                    updated_at: z.ZodString;
                    created_by: z.ZodString;
                    org_id: z.ZodString;
                    name: z.ZodString;
                    description: z.ZodNullable<z.ZodString>;
                    source_type: z.ZodEnum<{
                        email: "email";
                        queue: "queue";
                        webhook: "webhook";
                        schedule: "schedule";
                    }>;
                    source_ref_id: z.ZodString;
                    source_config: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    status: z.ZodEnum<{
                        enabled: "enabled";
                        disabled: "disabled";
                    }>;
                    graph_json: z.ZodNullable<z.ZodRecord<z.ZodString, z.ZodUnknown>>;
                    execution_count: z.ZodOptional<z.ZodNumber>;
                    link: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>;
            }, z.core.$strip>;
            stripRequired: boolean;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            graph_json: {
                nodes: {
                    id: string;
                    type: string;
                }[];
                edges: {
                    id: string;
                    source: string;
                    target: string;
                }[];
            };
            name?: undefined;
            source_type?: undefined;
            source_ref_id?: undefined;
            status?: undefined;
            payload?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: z.ZodObject<{
                    payload: z.ZodUnknown;
                }, z.core.$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                execution_id: z.ZodString;
                status: z.ZodString;
                steps: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    node_id: z.ZodString;
                    node_type: z.ZodString;
                    status: z.ZodString;
                    output: z.ZodOptional<z.ZodUnknown>;
                    error: z.ZodOptional<z.ZodString>;
                }, z.core.$strip>>>;
                error: z.ZodOptional<z.ZodString>;
            }, z.core.$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            payload: {
                event: string;
                data: {
                    key: string;
                };
            };
            name?: undefined;
            source_type?: undefined;
            source_ref_id?: undefined;
            status?: undefined;
            graph_json?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodObject<{
                total_workflows: z.ZodNumber;
                enabled_workflows: z.ZodNumber;
                disabled_workflows: z.ZodNumber;
                total_executions: z.ZodNumber;
                succeeded_executions: z.ZodNumber;
                failed_executions: z.ZodNumber;
                last_activity_at: z.ZodNullable<z.ZodString>;
            }, z.core.$strip>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                workflow_id: z.ZodString;
                status: z.ZodEnum<{
                    pending: "pending";
                    failed: "failed";
                    completed: "completed";
                    running: "running";
                }>;
                started_at: z.ZodNullable<z.ZodString>;
                completed_at: z.ZodNullable<z.ZodString>;
                error: z.ZodNullable<z.ZodString>;
                steps: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    node_id: z.ZodString;
                    node_type: z.ZodString;
                    status: z.ZodString;
                    started_at: z.ZodNullable<z.ZodString>;
                    completed_at: z.ZodNullable<z.ZodString>;
                    error: z.ZodNullable<z.ZodString>;
                }, z.core.$strip>>>;
            }, z.core.$strip>>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: z.ZodArray<z.ZodObject<{
                id: z.ZodString;
                workflow_id: z.ZodString;
                execution_id: z.ZodString;
                destination_type: z.ZodString;
                destination_id: z.ZodString;
                status: z.ZodEnum<{
                    success: "success";
                    pending: "pending";
                    failed: "failed";
                }>;
                sent_at: z.ZodNullable<z.ZodString>;
                response: z.ZodNullable<z.ZodUnknown>;
                error: z.ZodNullable<z.ZodString>;
            }, z.core.$strip>>;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=workflow.d.ts.map