declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                    internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                created_at: import("zod").ZodString;
                updated_at: import("zod").ZodString;
                created_by: import("zod").ZodString;
                name: import("zod").ZodString;
                description: import("zod").ZodNullable<import("zod").ZodString>;
                url: import("zod").ZodOptional<import("zod").ZodString>;
                internal: import("zod").ZodBoolean;
                metadata: import("zod").ZodNullable<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            type?: undefined;
            config?: undefined;
        };
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    name: import("zod").ZodString;
                    description: import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            type?: undefined;
            config?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    type: import("zod").ZodEnum<{
                        url: "url";
                    }>;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            type: string;
            config: {
                url: string;
            };
            name?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    config: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            config: {
                url: string;
            };
            name?: undefined;
            type?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseFields?: undefined;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                id: import("zod").ZodString;
                date: import("zod").ZodString;
                webhook_id: import("zod").ZodString;
                headers: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>;
                payload: import("zod").ZodUnknown;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name?: undefined;
            type?: undefined;
            config?: undefined;
        };
        responseFields?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=webhook.d.ts.map